==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ReferentialAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.BaseAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;

import java.util.Arrays;
import java.util.List;


public class ReferentialAttributeSetImpl extends InstanceSet<ReferentialAttributeSet,ReferentialAttribute> implements ReferentialAttributeSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setRef_Mode( int m_Ref_Mode ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setRef_Mode( m_Ref_Mode );
    }
    @Override
    public void setBAttr_ID( UniqueId ref_BAttr_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setBAttr_ID( ref_BAttr_ID );
    }
    @Override
    public void setBaseAttrName( String m_BaseAttrName ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setBaseAttrName( m_BaseAttrName );
    }
    @Override
    public void setBObj_ID( UniqueId ref_BObj_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setBObj_ID( ref_BObj_ID );
    }


    // selections
    @Override
    public O_ATTRSet R106_is_a_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( ReferentialAttribute referentialattribute : this ) o_attrset.add( referentialattribute.R106_is_a_O_ATTR() );
        return o_attrset;
    }
    @Override
    public AttributeReferenceInClassSet R108_resolves__AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( ReferentialAttribute referentialattribute : this ) attributereferenceinclassset.addAll( referentialattribute.R108_resolves__AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }
    @Override
    public BaseAttributeSet R113_navigates_back_to_BaseAttribute() throws XtumlException {
        BaseAttributeSet baseattributeset = new BaseAttributeSetImpl();
        for ( ReferentialAttribute referentialattribute : this ) baseattributeset.add( referentialattribute.R113_navigates_back_to_BaseAttribute() );
        return baseattributeset;
    }


    @Override
    public ReferentialAttribute nullElement() {
        return ReferentialAttributeImpl.EMPTY_REFERENTIALATTRIBUTE;
    }

    @Override
    public ReferentialAttributeSet emptySet() {
      return new ReferentialAttributeSetImpl();
    }

    @Override
    public ReferentialAttributeSet value() {
        return this;
    }

    @Override
    public List<ReferentialAttribute> elements() {
        return Arrays.asList(toArray(new ReferentialAttribute[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ReferentialAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.BaseAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ReferentialAttributeSetImpl extends InstanceSet<ReferentialAttributeSet,ReferentialAttribute> implements ReferentialAttributeSet {

    public ReferentialAttributeSetImpl() {
    }

    public ReferentialAttributeSetImpl(Comparator<? super ReferentialAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRef_Mode( int m_Ref_Mode ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setRef_Mode( m_Ref_Mode );
    }
    @Override
    public void setBaseAttrName( String m_BaseAttrName ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setBaseAttrName( m_BaseAttrName );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setBAttr_ID( UniqueId ref_BAttr_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setBAttr_ID( ref_BAttr_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setBObj_ID( UniqueId ref_BObj_ID ) throws XtumlException {
        for ( ReferentialAttribute referentialattribute : this ) referentialattribute.setBObj_ID( ref_BObj_ID );
    }


    // selections
    @Override
    public O_ATTRSet R106_is_a_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( ReferentialAttribute referentialattribute : this ) o_attrset.add( referentialattribute.R106_is_a_O_ATTR() );
        return o_attrset;
    }
    @Override
    public AttributeReferenceInClassSet R108_resolves__AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( ReferentialAttribute referentialattribute : this ) attributereferenceinclassset.addAll( referentialattribute.R108_resolves__AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }
    @Override
    public BaseAttributeSet R113_navigates_back_to_BaseAttribute() throws XtumlException {
        BaseAttributeSet baseattributeset = new BaseAttributeSetImpl();
        for ( ReferentialAttribute referentialattribute : this ) baseattributeset.add( referentialattribute.R113_navigates_back_to_BaseAttribute() );
        return baseattributeset;
    }


    @Override
    public ReferentialAttribute nullElement() {
        return ReferentialAttributeImpl.EMPTY_REFERENTIALATTRIBUTE;
    }

    @Override
    public ReferentialAttributeSet emptySet() {
      return new ReferentialAttributeSetImpl();
    }

    @Override
    public ReferentialAttributeSet emptySet(Comparator<? super ReferentialAttribute> comp) {
      return new ReferentialAttributeSetImpl(comp);
    }

    @Override
    public ReferentialAttributeSet value() {
        return this;
    }

    @Override
    public List<ReferentialAttribute> elements() {
        return Arrays.asList(toArray(new ReferentialAttribute[0]));
    }

}
